From 5615702859a48fc80a235911907fb634b79d9958 Mon Sep 17 00:00:00 2001
From: Raghav Gururajan <raghavgururajan@disroot.org>
Date: Tue, 14 Jan 2020 17:48:36 -0500
Subject: [PATCH] gnu: Add gnome-boxes.

* gnu/packages/gnome.scm (gnome-boxes): New variable.
---
 gnu/packages/gnome.scm | 57 ++++++++++++++++++++++++++++++++++++++++++
 1 file changed, 57 insertions(+)

diff --git a/gnu/packages/gnome.scm b/gnu/packages/gnome.scm
index 7ce9972460..9b63f555e1 100644
--- a/gnu/packages/gnome.scm
+++ b/gnu/packages/gnome.scm
@@ -246,6 +246,63 @@ Desktop.  It is designed to be as simple as possible and has some unique
 features to enable users to create their discs easily and quickly.")
     (license license:gpl2+)))
 
+(define-public gnome-boxes
+  (package
+   (name "gnome-boxes")
+   (version "3.32.2")
+   (source (origin
+            (method url-fetch)
+            (uri (string-append "mirror://gnome/sources/" name "/"
+                                (version-major+minor version) "/"
+                                name "-" version ".tar.xz"))
+            (sha256
+             (base32
+              "15g2w2hzh3945qcwfl3dyqnn5770lzg5cjwwzzj0lw9m98n4ljgn"))))
+   (build-system meson-build-system)
+   (arguments
+    '(#:glib-or-gtk? #t
+      #:configure-flags
+      (list "-Dsystemduserunitdir=no"
+            "-Dtmpfilesdir=no"
+            ;; Required for RUNPATH validation.
+            (string-append "-Dc_link_args=-Wl,-rpath="
+                           (assoc-ref %outputs "out") "/lib/gnome-boxes"))))
+   (native-inputs
+    `(("desktop-file-utils" ,desktop-file-utils)
+      ("gettext" ,gettext-minimal)
+      ("glib:bin" ,glib "bin")
+      ("gtk+:bin" ,gtk+ "bin")
+      ("itstool" ,itstool)
+      ("pkg-config" ,pkg-config)
+      ("vala" ,vala)))
+   (inputs
+    `(("adwaita-icon-theme" ,adwaita-icon-theme)
+      ("freerdp" ,freerdp)
+      ("govirt" ,libgovirt)
+      ("gtk-vnc" ,gtk-vnc)
+      ("json-glib" ,json-glib)
+      ("libarchive" ,libarchive)
+      ("libgudev" ,libgudev)
+      ("libosinfo" ,libosinfo)
+      ("libsecret" ,libsecret)
+      ("libusb" ,libusb)
+      ("libvirt-glib" ,libvirt-glib)
+      ("librest" ,rest)
+      ("spice-gtk" ,spice-gtk)
+      ("tracker" ,tracker)
+      ("tracker-miners" ,tracker-miners)
+      ("vte" ,vte)
+      ("webkitgtk" ,webkitgtk)))
+   (synopsis "Virtualization for GNOME desktop")
+   (description "GNOME Boxes is a simple application to view, access,
+and manage remote and virtual systems.")
+   (home-page "https://wiki.gnome.org/Apps/Boxes")
+   (license (list
+             ;; For data/icons/empty-boxes.png.
+             license:cc-by2.0
+             ;; For all others.
+             license:lgpl2+))))
+
 (define-public sushi
   (package
    (name "sushi")
-- 
2.24.1

